@@ -35,6 +35,12 @@
 
 #include "configeditor.h"
 
+void ConfigEditor::setGtk3ConfigValueDconf(const QString &paramName, bool paramValue, const QString &category)
+{
+    g_autoptr(GSettings) gsettings = g_settings_new(category.toUtf8().constData());
+    g_settings_set_boolean(gsettings, paramName.toUtf8().constData(), paramValue);
+}
+
 void ConfigEditor::setGtk3ConfigValueDconf(const QString &paramName, const QString &paramValue, const QString &category)
 {
     g_autoptr(GSettings) gsettings = g_settings_new(category.toUtf8().constData());
@@ -103,7 +109,7 @@ QString ConfigEditor::gtk2ConfigValue(const QString& paramName)
         }
     }
 
-    return QStringLiteral("Breeze");
+    return QString();
 }
 
 QString ConfigEditor::gtk3ConfigValueSettingsIni(const QString& paramName)
@@ -114,7 +120,7 @@ QString ConfigEditor::gtk3ConfigValueSettingsIni(const QString& paramName)
     KSharedConfig::Ptr gtk3Config = KSharedConfig::openConfig(gtk3ConfigPath, KConfig::NoGlobals);
     KConfigGroup group = gtk3Config->group(QStringLiteral("Settings"));
 
-    return group.readEntry(paramName, QStringLiteral("Breeze"));
+    return group.readEntry(paramName);
 }
 
 
@@ -164,6 +170,7 @@ void ConfigEditor::replaceValueInGtkrcContents(QString &gtkrcContents, const QSt
         QStringLiteral("gtk-menu-images"),
         QStringLiteral("gtk-button-images"),
         QStringLiteral("gtk-primary-button-warps-slider"),
+        QStringLiteral("gtk-enable-animations"),
     };
 
     QString newConfigString;
@@ -189,6 +196,7 @@ void ConfigEditor::replaceValueInXSettingsdContents(QString &xSettingsdContents,
         QStringLiteral("Gtk/MenuImages"),
         QStringLiteral("Gtk/ToolbarStyle"),
         QStringLiteral("Gtk/PrimaryButtonWarpsSlider"),
+        QStringLiteral("Gtk/EnableAnimations"),
     };
 
     QString newConfigString;
